@@ -95,13 +95,17 @@ def cli(ctx, project_file, verbose, confirm, project_id, region_name, account_id
         click.echo(click.style(f"Loaded {project_file}:", fg="cyan"))
         pprint(config)
         click.echo("")
-        click.echo(click.style(f"Using role_arn:     {config['role_arn']}", fg="cyan"))
-        click.echo(click.style(f"Using region_name:  {config['region_name']}", fg="cyan"))
-        click.echo(click.style(f"Running as role:    {user_arn}", fg="cyan"))
-        if user_arn != underlying_user_arn:
-            click.echo(click.style(f"Underlying role:    {underlying_user_arn}", fg="cyan"))
 
-        click.echo(click.style(f"Using account_id:       {config['account_id']}", fg="cyan"))
+        lines = [
+            f"Using role ARN:   {config['role_arn']}",
+            f"IN region:        {config['region_name']}",
+            f"Running as role:  {user_arn}",
+            f"Underlying role:  {underlying_user_arn}" if user_arn != underlying_user_arn else "",
+            f"Using account ID: {config['account_id']}"
+        ]
+
+        message = "\n".join([ln for ln in lines if ln])
+        click.echo(click.style(message, fg="cyan"))
         click.echo("")
 
     ctx.obj = {
@@ -268,6 +272,8 @@ def _prepare(project, from_label, description):
     new_release = release["new_release"]
 
     click.echo(click.style(f"Prepared release from images in {from_label}", fg="green"))
+    if prev_release is None:
+        click.echo(click.style("This is your first release for this project!", fg="yellow"))
     click.echo(click.style(f"Requested by: {new_release['requested_by']}", fg="yellow"))
     click.echo(click.style(f"Date created: {new_release['date_created']}", fg="yellow"))
     click.echo("")
@@ -286,7 +292,10 @@ def _prepare(project, from_label, description):
         #
         #     {ecr_repo_uri}/{namespace}/{service}:ref.{git_commit}
         #
-        prev_git_commit = prev_release["images"].get(service, "").split(".")[-1][:7]
+        prev_git_commit = "-------"
+        if prev_release is not None:
+            prev_git_commit = prev_release["images"].get(service, "").split(".")[-1][:7]
+
         new_git_commit = image.split(".")[-1][:7]
 
         rows.append([
